@@ -26,7 +26,7 @@
 typedef size_t gsize;
 typedef ptrdiff_t gssize;
 
-#define G_GSIZE_FORMAT   "%lu"
+#define G_GSIZE_FORMAT   "lu"
 
 #if defined (HOST_WATCHOS)
 #undef G_BREAKPOINT
